#!/bin/sh
#
# Create entries in /etc/profile.d and other post-install stuff
#

# Create a symlink for lpr
cd $SETUP_INSTALLPATH/bin
ln -sf llpr lpr

# Generate the bare-bones config file and symlink it in /etc
$SETUP_INSTALLPATH/cfggen $SETUP_INSTALLPATH
ln -sf $SETUP_INSTALLPATH/linuxprint.cfg /etc/linuxprint.cfg

# Try to use /etc/alternatives if it is available

if [ -d /etc/alternatives -a -L /usr/bin/lpr ]; then
	# Call the update-alternatives command to handle this
	if test -f /etc/alternatives/print; then
	    ALT=print
		# RedHat alternatives. We need to handle slave alternatives too
		# Try to detect which one is being used
		if ls -l /etc/alternatives/print | grep cups > /dev/null; then
			SYS=cups
			ln -sf llpr llpr.cups
			INITSCRIPT=cups
		else
			SYS=LPRng
			ln -sf llpr llpr.LPRng
			INITSCRIPT=lpd
		fi
		update-alternatives --install /usr/bin/lpr $ALT $SETUP_INSTALLPATH/bin/llpr.$SYS 90 \
			--slave /usr/bin/lp print-lp $SETUP_INSTALLPATH/bin/llpr.$SYS \
			--slave /usr/bin/lpq print-lpq /usr/bin/lpq.$SYS \
			--slave /usr/bin/cancel print-cancel /usr/bin/cancel.$SYS \
			--slave /usr/bin/lprm print-lprm /usr/bin/lprm.$SYS \
			--slave /usr/bin/lpstat print-lpstat /usr/bin/lpstat.$SYS \
			--slave /usr/sbin/lpc print-lpc /usr/sbin/lpc.$SYS \
			--slave /usr/share/man/man1/lp.1.gz print-lpman /usr/share/man/man1/lp-$SYS.1* \
			--slave /usr/share/man/man1/cancel.1.gz print-cancelman /usr/share/man/man1/cancel-$SYS.1* \
			--slave /usr/share/man/man1/lpq.1.gz print-lpqman /usr/share/man/man1/lpq-$SYS.1* \
			--slave /usr/share/man/man1/lpr.1.gz print-lprman /usr/share/man/man1/lpr-$SYS.1* \
			--slave /usr/share/man/man1/lprm.1.gz print-lprmman /usr/share/man/man1/lprm-$SYS.1* \
			--slave /usr/share/man/man1/lpstat.1.gz print-lpstatman /usr/share/man/man1/lpstat-$SYS.1* \
			--slave /usr/share/man/man8/lpc.8.gz print-lpcman /usr/share/man/man8/lpc-$SYS.8* \
			--initscript $INITSCRIPT
		update-alternatives --remove $ALT /usr/bin/lpr.$SYS
	else
	    ALT=lpr
		update-alternatives --install /usr/bin/lpr $ALT $SETUP_INSTALLPATH/bin/llpr 90 
	fi
	update-alternatives --auto $ALT
else
	if [ -d /etc/profile.d ]; then
		# Bash entry

		if [ ! -f /etc/profile.d/linux.sh ]; then
			cat > /etc/profile.d/linux.sh <<EOF
#!/bin/sh
# Put the Linux directory first in the path so that we can replace lpr
PATH=$SETUP_INSTALLPATH/bin:\$PATH
export PATH
EOF
			chmod 755 /etc/profile.d/linux.sh
		fi

		# CSH/TCSH entry
	
		if [ ! -f /etc/profile.d/linux.csh ]; then
			cat > /etc/profile.d/linux.csh <<EOF
#!/bin/sh
# Put the Linux directory first in the path so that we can replace lpr
setenv PATH $SETUP_INSTALLPATH/bin:\$PATH
EOF
			chmod 755 /etc/profile.d/linux.csh
		fi
	else
	# We need to modify /etc/profile if it exists
		if [ -w /etc/profile ]; then
			cp /etc/profile /etc/profile.bak
			echo export PATH=$SETUP_INSTALLPATH/bin:\$PATH \#__LINUX__ >> /etc/profile
		fi
	fi
fi
